:orphan:

Meet Sphinxit!
==============

.. figure::  _static/images/sp_logo.png
   :align:   center

Hello and welcome to the **Sphinxit** documentation. 
I recommend you to get started with :ref:`installation` and then head over to the :ref:`usage` tutorial.

**Sphinxit** is light and powerful **SphinxQL** query constructor, thin integration layer 
between your Python application and `Sphinx <http://sphinxsearch.com/>`_ search engine. 
Sphinxit is framework-free library, you can use it anywhere you need powerful Sphinx-based search.
Forget about deprecated Sphinx API or unpredictable non-tested batteries. Sphinxit is just better.

Sphinxit documentation doesn`t cover whole Sphinx possibilities and if you are not familiar with 
Sphinx search engine or you need some kind of Sphinx-specific documentation, visit it`s 
`official website <http://sphinxsearch.com/docs/current.html>`_.

.. include:: contents.rst.inc
